Core Models
===========

.. module:: jamb.core.models

Data models for requirements items, test links, coverage, and the traceability graph.

Item
----

.. autoclass:: Item
   :members:

LinkedTest
----------

.. autoclass:: LinkedTest
   :members:

ItemCoverage
------------

.. autoclass:: ItemCoverage
   :members:

TraceabilityGraph
-----------------

.. autoclass:: TraceabilityGraph
   :members:

JambError
---------

.. module:: jamb.core.errors

.. autoclass:: JambError
   :members:
